@@ -406,16 +406,16 @@ class MyHandler(BaseHTTPRequestHandler):
             forward_model = ForwardModel(earth_model, seismic_model,
                                          plots)
 
-            prof.runctx('self.run_json(forward_model)',
-                        {'self': self, 'forward_model':forward_model},
-                        {},
-                        'profile.test')
+            #prof.runctx('self.run_json(forward_model)',
+            #            {'self': self, 'forward_model':forward_model},
+            #            {},
+            #            'profile.test')
 
-            #p = mp.Process(target=self.run_json,
-            #               args=(forward_model,))
+            p = mp.Process(target=self.run_json,
+                           args=(forward_model,))
 
-            #p.start()
-            #p.join()
+            p.start()
+            p.join()
 
             return
 
